# Generated by Django 4.2.6 on 2024-08-18 23:30

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import unconference.models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("unconference", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="UserEventData",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("data", models.JSONField(default=unconference.models.default_data)),
                (
                    "unconference_event",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="unconference.unconferenceevent",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
    ]
